<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>RestrictOrthogonal</name>
    <message>
        <location filename="../RestrictOrthogonalInit.js" line="+2"/>
        <source>Restrict &amp;Orthogonally</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Ograniczaj &amp;prostopadle</translatorcomment>
        <translation>Ograniczanie p&amp;rostopadle</translation>
    </message>
</context>
</TS>
